```{include} ../README.md

```

```{toctree}
:hidden:
:maxdepth: 3
:caption: API Reference

apidocs/django_twc_toolbox/django_twc_toolbox.rst
```

```{toctree}
:hidden:
:maxdepth: 3
:caption: Development

development/contributing.md
development/just.md
Releasing <development/releasing.md>
```
